@@ -26,10 +26,11 @@
 #' `terms` (the selectors or variables selected) and `value` for the
 #' estimated threshold is returned.
 #'
-#' @examples
+#' @template case-weights-not-supported
+#'
+#' @examplesIf rlang::is_installed("modeldata")
 #' library(recipes)
-#' library(modeldata)
-#' data(biomass)
+#' data(biomass, package = "modeldata")
 #'
 #' ## Truncate some values to emulate what a lower limit of
 #' ## the measurement system might look like
@@ -37,11 +38,13 @@
 #' biomass$carbon <- ifelse(biomass$carbon > 40, biomass$carbon, 40)
 #' biomass$hydrogen <- ifelse(biomass$hydrogen > 5, biomass$carbon, 5)
 #'
-#' biomass_tr <- biomass[biomass$dataset == "Training",]
-#' biomass_te <- biomass[biomass$dataset == "Testing",]
+#' biomass_tr <- biomass[biomass$dataset == "Training", ]
+#' biomass_te <- biomass[biomass$dataset == "Testing", ]
 #'
-#' rec <- recipe(HHV ~ carbon + hydrogen + oxygen + nitrogen + sulfur,
-#'               data = biomass_tr)
+#' rec <- recipe(
+#'   HHV ~ carbon + hydrogen + oxygen + nitrogen + sulfur,
+#'   data = biomass_tr
+#' )
 #'
 #' impute_rec <- rec %>%
 #'   step_impute_lower(carbon, hydrogen)
@@ -55,8 +58,8 @@
 #' transformed_te <- bake(impute_rec, biomass_te)
 #'
 #' plot(transformed_te$carbon, biomass_te$carbon,
-#'      ylab = "pre-imputation", xlab = "imputed")
-
+#'   ylab = "pre-imputation", xlab = "imputed"
+#' )
 step_impute_lower <-
   function(recipe,
            ...,
@@ -87,7 +90,7 @@ step_lowerimpute <- function(recipe,
                              threshold = NULL,
                              skip = FALSE,
                              id = rand_id("impute_lower")) {
-  lifecycle::deprecate_warn(
+  lifecycle::deprecate_stop(
     when = "0.1.16",
     what = "recipes::step_lowerimpute()",
     with = "recipes::step_impute_lower()"
@@ -122,17 +125,15 @@ prep.step_impute_lower <- function(x, training, info = NULL, ...) {
   check_type(training[, col_names])
 
   threshold <-
-    vapply(training[, col_names],
-           min,
-           numeric(1),
-           na.rm = TRUE)
-  if (any(threshold < 0))
+    vapply(training[, col_names], min, numeric(1), na.rm = TRUE)
+  if (any(threshold < 0)) {
     rlang::abort(
       paste0(
         "Some columns have negative values. Lower bound ",
         "imputation is intended for data bounded at zero."
       )
     )
+  }
   step_impute_lower_new(
     terms = x$terms,
     role = x$role,
@@ -149,13 +150,18 @@ prep.step_lowerimpute <- prep.step_impute_lower
 
 #' @export
 bake.step_impute_lower <- function(object, new_data, ...) {
+  check_new_data(names(object$threshold), object, new_data)
+
   for (i in names(object$threshold)) {
     affected <- which(new_data[[i]] <= object$threshold[[i]])
-    if (length(affected) > 0)
-      new_data[[i]][affected] <- runif(length(affected),
-                                      max = object$threshold[[i]])
+    if (length(affected) > 0) {
+      new_data[[i]][affected] <- runif(
+        length(affected),
+        max = object$threshold[[i]]
+      )
+    }
   }
-  as_tibble(new_data)
+  new_data
 }
 
 #' @export
@@ -178,8 +184,10 @@ print.step_lowerimpute <- print.step_impute_lower
 #' @export
 tidy.step_impute_lower <- function(x, ...) {
   if (is_trained(x)) {
-    res <- tibble(terms = names(x$threshold),
-                  value = unname(x$threshold))
+    res <- tibble(
+      terms = names(x$threshold),
+      value = unname(x$threshold)
+    )
   } else {
     term_names <- sel2char(x$terms)
     res <- tibble(terms = term_names, value = na_dbl)
