@@ -20,10 +20,10 @@ dat_te <- data.frame(
   z = factor(rep_len(letters[3:1], 10))
 )
 
-rec <- recipe(y ~ .,  data = dat_tr)
+rec <- recipe(y ~ ., data = dat_tr)
 
-test_that('non-factor variables with dot', {
-  int_rec <- rec %>% step_interact( ~ (. - y- z) ^ 3 , sep = ":")
+test_that("non-factor variables with dot", {
+  int_rec <- rec %>% step_interact(~ (. - y - z)^3, sep = ":")
   int_rec_trained <-
     prep(int_rec, training = dat_tr, verbose = FALSE)
 
@@ -32,8 +32,8 @@ test_that('non-factor variables with dot', {
   te_new <- te_new[, sort(names(te_new))]
   te_new <- as.matrix(te_new)
 
-  og_terms <- terms( ~ (. - y - z) ^ 3, data = dat_te)
-  te_og <- model.matrix(og_terms, data = dat_te)[,-1]
+  og_terms <- terms(~ (. - y - z)^3, data = dat_te)
+  te_og <- model.matrix(og_terms, data = dat_te)[, -1]
   te_og <- te_og[, sort(colnames(te_og))]
 
   rownames(te_new) <- NULL
@@ -43,8 +43,8 @@ test_that('non-factor variables with dot', {
 })
 
 
-test_that('non-factor variables with specific variables', {
-  int_rec <- rec %>% step_interact( ~ x1:x2 + x3:x4:x5, sep = ":")
+test_that("non-factor variables with specific variables", {
+  int_rec <- rec %>% step_interact(~ x1:x2 + x3:x4:x5, sep = ":")
   int_rec_trained <-
     prep(int_rec, training = dat_tr, verbose = FALSE)
 
@@ -53,9 +53,9 @@ test_that('non-factor variables with specific variables', {
   te_new <- te_new[, sort(names(te_new))]
   te_new <- as.matrix(te_new)
 
-  og_terms <- terms( ~ x1 + x2 + x3 + x4 + x5 +
-                       x1:x2 + x3:x4:x5, data = dat_te)
-  te_og <- model.matrix(og_terms, data = dat_te)[,-1]
+  og_terms <- terms(~ x1 + x2 + x3 + x4 + x5 +
+    x1:x2 + x3:x4:x5, data = dat_te)
+  te_og <- model.matrix(og_terms, data = dat_te)[, -1]
   te_og <- te_og[, sort(colnames(te_og))]
 
   rownames(te_new) <- NULL
@@ -65,10 +65,10 @@ test_that('non-factor variables with specific variables', {
 })
 
 
-test_that('using selectors', {
+test_that("using selectors", {
   int_rec <- rec %>%
     step_dummy(z) %>%
-    step_interact( ~ starts_with("z"):x1)
+    step_interact(~ starts_with("z"):x1)
   int_rec_trained <-
     prep(int_rec, training = dat_tr, verbose = FALSE)
 
@@ -76,12 +76,14 @@ test_that('using selectors', {
     bake(int_rec_trained, new_data = dat_te, all_predictors(), -all_nominal())
   te_new <- te_new[, sort(names(te_new))]
   te_new <- as.matrix(te_new)
-  te_new <- te_new[, c("x1", "x2", "x3", "x4", "x5",
-                       "z_b", "z_c", "z_b_x_x1", "z_c_x_x1")]
+  te_new <- te_new[, c(
+    "x1", "x2", "x3", "x4", "x5",
+    "z_b", "z_c", "z_b_x_x1", "z_c_x_x1"
+  )]
 
-  og_terms <- terms( ~ x1 + x2 + x3 + x4 + x5 +
-                       x1*z, data = dat_te)
-  te_og <- model.matrix(og_terms, data = dat_te)[,-1]
+  og_terms <- terms(~ x1 + x2 + x3 + x4 + x5 +
+    x1 * z, data = dat_te)
+  te_og <- model.matrix(og_terms, data = dat_te)[, -1]
   colnames(te_og) <- gsub(":", "_x_", colnames(te_og), fixed = TRUE)
   colnames(te_og) <- gsub("zb", "z_b", colnames(te_og), fixed = TRUE)
   colnames(te_og) <- gsub("zc", "z_c", colnames(te_og), fixed = TRUE)
@@ -97,10 +99,10 @@ test_that('using selectors', {
 
 # Tests related to #648
 # https://github.com/tidymodels/recipes/issues/648
-test_that('using selectors when namespaces with ::', {
+test_that("using selectors when namespaces with ::", {
   int_rec <- rec %>%
     step_dummy(z) %>%
-    step_interact( ~ tidyselect::starts_with("z"):x1)
+    step_interact(~ tidyselect::starts_with("z"):x1)
   int_rec_trained <-
     prep(int_rec, training = dat_tr, verbose = FALSE)
 
@@ -108,12 +110,14 @@ test_that('using selectors when namespaces with ::', {
     bake(int_rec_trained, new_data = dat_te, all_predictors(), -all_nominal())
   te_new <- te_new[, sort(names(te_new))]
   te_new <- as.matrix(te_new)
-  te_new <- te_new[, c("x1", "x2", "x3", "x4", "x5",
-                       "z_b", "z_c", "z_b_x_x1", "z_c_x_x1")]
+  te_new <- te_new[, c(
+    "x1", "x2", "x3", "x4", "x5",
+    "z_b", "z_c", "z_b_x_x1", "z_c_x_x1"
+  )]
 
-  og_terms <- terms( ~ x1 + x2 + x3 + x4 + x5 +
-                       x1*z, data = dat_te)
-  te_og <- model.matrix(og_terms, data = dat_te)[,-1]
+  og_terms <- terms(~ x1 + x2 + x3 + x4 + x5 +
+    x1 * z, data = dat_te)
+  te_og <- model.matrix(og_terms, data = dat_te)[, -1]
   colnames(te_og) <- gsub(":", "_x_", colnames(te_og), fixed = TRUE)
   colnames(te_og) <- gsub("zb", "z_b", colnames(te_og), fixed = TRUE)
   colnames(te_og) <- gsub("zc", "z_c", colnames(te_og), fixed = TRUE)
@@ -129,7 +133,7 @@ test_that('using selectors when namespaces with ::', {
 test_that("using where() works", {
   ex_rec <- rec %>%
     step_dummy(z) %>%
-    step_interact( ~ where(is.numeric):x1)
+    step_interact(~ where(is.numeric):x1)
 
   x <- prep(ex_rec, dat_tr)
 
@@ -146,7 +150,7 @@ test_that("using all_of() works", {
   xvars <- c("x2", "x3")
 
   ex_rec <- rec %>%
-    step_interact( ~ all_of(xvars):x1)
+    step_interact(~ all_of(xvars):x1)
 
   x <- prep(ex_rec, dat_tr)
 
@@ -159,16 +163,16 @@ test_that("using all_of() works", {
   )
 })
 
-test_that('printing', {
-  int_rec <- rec %>% step_interact(~x1:x2)
-  expect_output(print(int_rec))
-  expect_output(prep(int_rec, training = dat_tr, verbose = TRUE))
+test_that("printing", {
+  int_rec <- rec %>% step_interact(~ x1:x2)
+  expect_snapshot(print(int_rec))
+  expect_snapshot(prep(int_rec))
 })
 
 # more missing data tests
 
 
-test_that('finding selectors in formulas', {
+test_that("finding selectors in formulas", {
   expect_equal(
     recipes:::find_selectors(
       ~ (a + b + starts_with("huh?")):has_role("something")
@@ -189,20 +193,20 @@ test_that('finding selectors in formulas', {
   )
   expect_equal(
     recipes:::find_selectors(
-      ~ a
+      ~a
     ),
     list()
   )
 })
 
-test_that('replacing selectors in formulas', {
+test_that("replacing selectors in formulas", {
   expect_equal(
     recipes:::replace_selectors(
       ~ (a + b + starts_with("huh?")):has_role("something"),
       quote(starts_with("huh?")),
-      quote((x1+x2+x3))
+      quote((x1 + x2 + x3))
     ),
-    expr(~(a + b + (x1 + x2 + x3)):has_role("something"))
+    expr(~ (a + b + (x1 + x2 + x3)):has_role("something"))
   )
   expect_equal(
     recipes:::replace_selectors(
@@ -210,7 +214,7 @@ test_that('replacing selectors in formulas', {
       quote(matches("wat?")),
       quote(a)
     ),
-    expr(~ (a) ^ 2)
+    expr(~ (a)^2)
   )
   expect_equal(
     recipes:::replace_selectors(
@@ -222,29 +226,31 @@ test_that('replacing selectors in formulas', {
   )
 })
 
-test_that('missing columns', {
+test_that("missing columns", {
+  skip("redundant with check_new_data checks")
+
   no_fail <-
     rec %>%
     step_rm(x1) %>%
-    step_interact(~x1:x2)
-  expect_warning(no_fail_rec <- prep(no_fail, dat_tr))
+    step_interact(~ x1:x2)
+  expect_snapshot(no_fail_rec <- prep(no_fail, dat_tr))
   no_fail_res <- juice(no_fail_rec) %>% names()
   expect_true(!any(grepl("_x_", no_fail_res)))
 
   one_int <-
     rec %>%
     step_rm(x1) %>%
-    step_interact(~x1:x2) %>%
-    step_interact(~x3:x2)
-  expect_warning(one_int_rec <- prep(one_int, dat_tr))
+    step_interact(~ x1:x2) %>%
+    step_interact(~ x3:x2)
+  expect_snapshot(one_int_rec <- prep(one_int, dat_tr))
   one_int_res <- juice(one_int_rec) %>% names()
   expect_true(sum(grepl("_x_", one_int_res)) == 1)
 
   with_selectors <-
     rec %>%
     step_rm(x1) %>%
-    step_interact(~starts_with("x"):starts_with("x")) %>%
-    step_interact(~x3:x2)
+    step_interact(~ starts_with("x"):starts_with("x")) %>%
+    step_interact(~ x3:x2)
   expect_warning(prep(with_selectors, dat_tr), regexp = NA)
 })
 
@@ -269,3 +275,20 @@ test_that('missing columns', {
 #   all.equal(te_og, te_new)
 # })
 
+
+test_that("bake method errors when needed non-standard role columns are missing", {
+  int_rec <- rec %>%
+    step_interact(~ starts_with("z"):x1, id = "") %>%
+    update_role(starts_with("z"):x1, new_role = "potato") %>%
+    update_role_requirements(role = "potato", bake = FALSE)
+
+  suppressWarnings(
+    int_rec_trained <-
+      prep(int_rec, training = dat_tr, verbose = FALSE)
+  )
+
+  expect_error(bake(int_rec_trained, dat_tr[, 4:6]),
+               class = "new_data_missing_column")
+
+  expect_snapshot(bake(int_rec_trained, dat_tr[, 4:6]), error = TRUE)
+})
