@@ -4,11 +4,11 @@ library(dplyr)
 
 # ------------------------------------------------------------------------------
 
-iris_rec <- recipe( ~ ., data = iris)
+iris_rec <- recipe(~., data = iris)
 
 # ------------------------------------------------------------------------------
 
-test_that('basic usage', {
+test_that("basic usage", {
   rec <-
     iris_rec %>%
     step_mutate(
@@ -42,7 +42,7 @@ test_that('basic usage', {
   expect_equal(dplyr_test, rec_test)
 })
 
-test_that('quasiquotation', {
+test_that("quasiquotation", {
   const <- 9.077
   rec_1 <-
     iris_rec %>%
@@ -66,7 +66,9 @@ test_that('quasiquotation', {
   prepped_2 <- prep(rec_2, training = iris %>% slice(1:75))
 
   rm(const)
-  expect_error(prep(rec_1, training = iris %>% slice(1:75)))
+  expect_snapshot(error = TRUE,
+    prep(rec_1, training = iris %>% slice(1:75))
+  )
   expect_error(
     prepped_2 <- prep(rec_2, training = iris %>% slice(1:75)),
     regexp = NA
@@ -95,7 +97,7 @@ test_that("can use unnamed expressions like `across()` (#759)", {
   )
 })
 
-test_that('no input', {
+test_that("no input", {
   no_inputs <-
     iris_rec %>%
     step_mutate() %>%
@@ -104,10 +106,10 @@ test_that('no input', {
   expect_equal(no_inputs, iris)
 })
 
-test_that('printing', {
+test_that("printing", {
   rec <- iris_rec %>% step_mutate(x = 5)
-  expect_output(print(rec))
-  expect_output(prep(rec, training = iris, verbose = TRUE))
+  expect_snapshot(print(rec))
+  expect_snapshot(prep(rec))
 })
 
 test_that("tidying allows for named and unnamed expressions", {
@@ -128,7 +130,7 @@ test_that("tidying allows for named and unnamed expressions", {
 
 # ------------------------------------------------------------------------------
 
-test_that('basic usage', {
+test_that("basic usage", {
   rec <-
     iris_rec %>%
     step_mutate_at(contains("Length"), fn = log)
@@ -159,7 +161,7 @@ test_that('basic usage', {
   expect_equal(dplyr_test, rec_test)
 })
 
-test_that('mulitple functions', {
+test_that("mulitple functions", {
   rec <-
     iris_rec %>%
     step_mutate_at(contains("Length"), fn = list(a = log, b = sqrt))
@@ -195,7 +197,8 @@ test_that('mulitple functions', {
 })
 
 
-test_that('no input', {
+test_that("no input", {
+  # Wait for call pass through
   expect_error(
     iris_rec %>%
       step_mutate_at() %>%
@@ -204,10 +207,10 @@ test_that('no input', {
   )
 })
 
-test_that('printing', {
+test_that("printing", {
   rec <- iris_rec %>% step_mutate_at(contains("Sepal"), fn = log)
-  expect_output(print(rec))
-  expect_output(prep(rec, training = iris, verbose = TRUE))
+  expect_snapshot(print(rec))
+  expect_snapshot(prep(rec))
 })
 
 test_that("mutate_at - empty selection prep/bake is a no-op", {
